pub struct Windows<R> { /* private fields */ }Expand description
Collection of windows with their associated renderers.
Implementations
Sourceimpl<R> Windows<R>
impl<R> Windows<R>
Sourcepub fn insert(&mut self, window_data: WindowData, renderer: R) -> WindowId
pub fn insert(&mut self, window_data: WindowData, renderer: R) -> WindowId
Inserts a window and its renderer. Returns the WindowId.
Sourcepub fn remove(&mut self, id: &WindowId) -> Option<(WindowData, R)>
pub fn remove(&mut self, id: &WindowId) -> Option<(WindowData, R)>
Removes a window by ID, returning its data and renderer if present.
Sourcepub fn get(&self, id: &WindowId) -> Option<&(WindowData, R)>
pub fn get(&self, id: &WindowId) -> Option<&(WindowData, R)>
Returns a reference to the window data and renderer for the given ID.
Sourcepub fn get_mut(&mut self, id: &WindowId) -> Option<&mut (WindowData, R)>
pub fn get_mut(&mut self, id: &WindowId) -> Option<&mut (WindowData, R)>
Returns a mutable reference to the window data and renderer for the given ID.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&WindowId, &(WindowData, R))>
pub fn iter(&self) -> impl Iterator<Item = (&WindowId, &(WindowData, R))>
Iterates over all windows.
Sourcepub fn iter_mut(
&mut self,
) -> impl Iterator<Item = (&WindowId, &mut (WindowData, R))>
pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (&WindowId, &mut (WindowData, R))>
Iterates mutably over all windows.